bread package
=============

.. automodule:: bread
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   bread.contrib
   bread.forms
   bread.layout
   bread.settings
   bread.utils
   bread.views

Submodules
----------

bread.context\_processors module
--------------------------------

.. automodule:: bread.context_processors
   :members:
   :undoc-members:
   :show-inheritance:

bread.formatters module
-----------------------

.. automodule:: bread.formatters
   :members:
   :undoc-members:
   :show-inheritance:

bread.menu module
-----------------

.. automodule:: bread.menu
   :members:
   :undoc-members:
   :show-inheritance:

bread.middleware module
-----------------------

.. automodule:: bread.middleware
   :members:
   :undoc-members:
   :show-inheritance:

bread.urls module
-----------------

.. automodule:: bread.urls
   :members:
   :undoc-members:
   :show-inheritance:
